package com.yeejoin.amos.patrol.service.business.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.yeejoin.amos.component.feign.config.InnerInvokException;
import com.yeejoin.amos.component.feign.model.FeignClientResult;
import com.yeejoin.amos.feign.privilege.model.AgencyUserModel;
import com.yeejoin.amos.feign.privilege.model.CompanyModel;
import com.yeejoin.amos.feign.privilege.model.DepartmentModel;
import com.yeejoin.amos.feign.privilege.model.IdPasswordAuthModel;
//import com.yeejoin.amos.op.core.common.response.CommonResponse;
//import com.yeejoin.amos.op.core.util.CommonResponseUtil;
import com.yeejoin.amos.patrol.common.core.response.bo.CompanyBo;
import com.yeejoin.amos.patrol.common.core.response.bo.DepartmentBo;
import com.yeejoin.amos.patrol.common.entity.CommonResponse;
import com.yeejoin.amos.patrol.common.entity.CommonResponseUtil;
import com.yeejoin.amos.patrol.common.entity.UserModel;
import com.yeejoin.amos.patrol.common.vo.DepartmentUserTreeWebVo;
import com.yeejoin.amos.patrol.service.business.param.AppLoginUserParam;
import com.yeejoin.amos.patrol.service.business.param.SelectUserInfo;
import com.yeejoin.amos.patrol.service.business.service.intfc.IAppService;
import com.yeejoin.amos.patrol.service.business.util.DesUtil;
import com.yeejoin.amos.patrol.service.business.vo.DepartmentUserTreeAppVo;
import com.yeejoin.amos.patrol.service.framework.ReginParams;
import com.yeejoin.amos.patrol.service.jpush.AppMessagePushService;
import com.yeejoin.amos.patrol.service.remote.RemoteSecurityService;
//import com.yeejoin.amos.security.common.authorization.Authorization;
//import com.yeejoin.amos.security.common.model.UserModel;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * 获取用户信息
 *
 * @author gaodongdong
 */
@RestController
@RequestMapping(value = "/api/user")
@Api(tags = "用户信息api")
public class UserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(UserController.class);

    @Autowired
    private RemoteSecurityService remoteSecurityService;

    @Autowired
    private IAppService iAppService;
    @Autowired
    private AppMessagePushService appMessagePushService;
    @Autowired
    private  com.yeejoin.amos.patrol.service.remote.feign.PushFeign PushFeign;
    private static final String appType = "APP";

    @Value("${security.productApp}")
    private String productApp;
    @Value("${security.appKeyApp}")
    private String appKeyApp;
    @Autowired
    private RestTemplate restTemplate;
    @Value("${Security.fegin.name}")
    private String SecurityName;
    /**
     * 根据部门id查询用户信息
     *
     * @param deptId
     * @return
     */
    @ApiOperation(value = "部门人员查询", notes = "部门人员查询")
    @RequestMapping(value = "/queryDeptUser", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse queryDeptUser(@RequestParam(value = "deptId", required = false) String deptId) {
        List<AgencyUserModel> userModels = remoteSecurityService.listUserByDepartmentId(getToken(), getProduct(), getAppKey(), deptId);
        List<LinkedHashMap<String, Object>> userList = paraseData(userModels, null);

        return CommonResponseUtil.success(userList);
    }




    
    
    @ApiOperation(value = "部门人员树查询", notes = "部门人员树查询")
    @RequestMapping(value = "/queryDeptUserTree1", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse queryDeptUserTree1() {
        ReginParams reginParams = getSelectedOrgInfo();

        CompanyModel companyModel = remoteSecurityService.listUserByCompanyId1(getToken(), getProduct(), getAppKey(), reginParams.getCompany().getSequenceNbr());

        List children = (List) companyModel.getChildren();

        List<DepartmentUserTreeWebVo> list = Lists.newArrayList();

        for (int i = 0; i < children.size(); i++) {
            Map<String, Object> map = (LinkedHashMap) children.get(i);
            JSONObject json = JSON.parseObject(JSON.toJSONString(map));
            DepartmentUserTreeWebVo deptTreeWeb = new DepartmentUserTreeWebVo();
            JSONArray childrens = json.getJSONArray("children");

            deptTreeWeb.setType("department");
            deptTreeWeb.setKey(map.get("sequenceNbr").toString());
            deptTreeWeb.setLabel(map.get("sequenceNbr").toString());
            deptTreeWeb.setTitle(map.get("departmentName").toString());
            deptTreeWeb.setValue(map.get("sequenceNbr").toString());
            if (!ObjectUtils.isEmpty(map.get("userModelList"))) {
                deptTreeWeb.setUserModelList((List) map.get("userModelList"));
            }
            list.add(deptTreeWeb);
            if (childrens != null && childrens.size() > 0) {
                buildUserDeptTreeForWebBefore(list, childrens);
            }

        }




        list = buildUserDeptTreeForWeb(list);

        return CommonResponseUtil.success(list);
    }

    /**
     * 部门数据预处理（获取所有子节点）
     *
     * @param list
     * @param children
     */
    private void buildUserDeptTreeForWebBefore(List<DepartmentUserTreeWebVo> list, JSONArray children) {
        for (int i = 0; i < children.size(); i++) {
            JSONObject json = children.getJSONObject(i);

            DepartmentUserTreeWebVo deptTreeWeb = new DepartmentUserTreeWebVo();

            Map deptMap = JSONObject.parseObject(json.toJSONString(), Map.class);
            deptTreeWeb.setType("department");
            deptTreeWeb.setKey(deptMap.get("sequenceNbr").toString());
            deptTreeWeb.setLabel(deptMap.get("sequenceNbr").toString());
            deptTreeWeb.setTitle(deptMap.get("departmentName").toString());
            deptTreeWeb.setValue(deptMap.get("sequenceNbr").toString());
            if (!ObjectUtils.isEmpty(deptMap.get("userModelList"))) {
                deptTreeWeb.setUserModelList((List) deptMap.get("userModelList"));
            }

            if (json != null && json.size() > 0) {
                list.add(deptTreeWeb);
            } else {

                JSONArray childrens = json.getJSONArray("children");
                if (childrens != null && childrens.size() > 0) {
                    buildUserDeptTreeForWebBefore(deptTreeWeb.getChildren(), childrens);
                }
                if ("0".equals(deptMap.get("parentId"))) {
                    list.add(deptTreeWeb);
                }
            }
        }
    }

    /**
     * 重构数据，用户存放在部门的children
     *
     * @param list
     * @return
     */
    private List<DepartmentUserTreeWebVo> buildUserDeptTreeForWeb(List<DepartmentUserTreeWebVo> list) {
        list.forEach(
          x -> {
              List<DepartmentUserTreeWebVo> users = Lists.newArrayList();

              if (!ObjectUtils.isEmpty(x.getUserModelList())) {

                  List<DepartmentUserTreeWebVo> collects = x.getUserModelList().stream().collect(Collectors.toList());
                  List<Map<String, Object>> userModelList = (List)collects;

                  userModelList.forEach(
                    userModel -> {
                        DepartmentUserTreeWebVo userTreeWeb = new DepartmentUserTreeWebVo();

                        userTreeWeb.setType("user");
                        userTreeWeb.setKey(userModel.get("userId").toString()+"*"+UUID.randomUUID().toString());
                        userTreeWeb.setLabel(userModel.get("realName").toString());
                        userTreeWeb.setTitle(userModel.get("realName").toString());
                        userTreeWeb.setValue(userModel.get("userId").toString()+"*"+UUID.randomUUID().toString());
                        users.add(userTreeWeb);
                    }
                  );
                  x.setChildren(users);
                  collects.clear();
                  x.setUserModelList(collects);
              }
          }
        );
        return list;
    }


    private void buildUserDeptTreeForWeb(List<DepartmentUserTreeWebVo> list, JSONArray children) {
        for (int i = 0; i < children.size(); i++) {
            JSONObject json = children.getJSONObject(i);
            if (json != null && json.size() > 0) {
                if ("user".equals(json.getString("type"))) {
                    DepartmentUserTreeWebVo userTreeWeb = new DepartmentUserTreeWebVo();
                    userTreeWeb.setType("user");
                    Map map = JSONObject.parseObject(json.getString("object"), Map.class);
                    userTreeWeb.setKey(map.get("userId") +"");
                    userTreeWeb.setLabel(map.get("realName") + "");
                    userTreeWeb.setTitle(map.get("realName") + "");
                    userTreeWeb.setValue(map.get("userId") + "");
                    list.add(userTreeWeb);
                } else {

                    DepartmentUserTreeWebVo deptTreeWeb = new DepartmentUserTreeWebVo();

                    Map map = JSONObject.parseObject(json.getString("object"), Map.class);
                    deptTreeWeb.setType("department");
                    deptTreeWeb.setKey(map.get("sequenceNbr") + "");
                    deptTreeWeb.setLabel(map.get("sequenceNbr") + "");
                    deptTreeWeb.setTitle(map.get("departmentName") + "");
                    deptTreeWeb.setValue(map.get("sequenceNbr") + "");

                    JSONArray childrens = json.getJSONArray("children");
                    if (childrens != null && childrens.size() > 0) {
                        buildUserDeptTreeForWeb(deptTreeWeb.getChildren(), childrens);

                    }
                    if ("0".equals(map.get("parentId"))) {
                        list.add(deptTreeWeb);
                    }
                }
            }
        }
    }


    private void buildUserDeptTreeForWeb1(List<DepartmentUserTreeWebVo> list, JSONArray children) {
        for (int i = 0; i < children.size(); i++) {
            JSONObject json = children.getJSONObject(i);
            if (json != null && json.size() > 0) {
                if (!ObjectUtils.isEmpty(json.getString("userModelList"))) {
                    DepartmentUserTreeWebVo userTreeWeb = new DepartmentUserTreeWebVo();
                    userTreeWeb.setType("user");
                    Map map = JSONObject.parseObject(json.getString("userModelList"), Map.class);
                    userTreeWeb.setKey(map.get("userId") + "");
                    userTreeWeb.setLabel(map.get("realName") + "");
                    userTreeWeb.setTitle(map.get("realName") + "");
                    userTreeWeb.setValue(map.get("userId") + "");
                    list.add(userTreeWeb);
                } else {

                    DepartmentUserTreeWebVo deptTreeWeb = new DepartmentUserTreeWebVo();

                    Map map = JSONObject.parseObject(json.getString("object"), Map.class);
                    deptTreeWeb.setType("department");
                    deptTreeWeb.setKey(map.get("sequenceNbr") + "");
                    deptTreeWeb.setLabel(map.get("sequenceNbr") + "");
                    deptTreeWeb.setTitle(map.get("departmentName") + "");
                    deptTreeWeb.setValue(map.get("sequenceNbr") + "");

                    JSONArray childrens = json.getJSONArray("children");
                    if (childrens != null && childrens.size() > 0) {
                        buildUserDeptTreeForWeb(deptTreeWeb.getChildren(), childrens);

                    }
                    if ("0".equals(map.get("parentId"))) {
                        list.add(deptTreeWeb);
                    }
                }
            }
        }
    }

    private void buildUserDeptTreeForWeb2(List<DepartmentUserTreeWebVo> list, JSONArray children) {
        for (int i = 0; i < children.size(); i++) {
            JSONObject json = children.getJSONObject(i);
            if (json != null && json.size() > 0) {
                if ("user".equals(json.getString("type"))) {
                    DepartmentUserTreeWebVo userTreeWeb = new DepartmentUserTreeWebVo();
                    userTreeWeb.setType("user");
                    Map map = JSONObject.parseObject(json.getString("object"), Map.class);
                    userTreeWeb.setKey(map.get("userId") + "");
                    userTreeWeb.setLabel(map.get("realName") + "");
                    userTreeWeb.setTitle(map.get("realName") + "");
                    userTreeWeb.setValue(map.get("userId") + "");
                    list.add(userTreeWeb);
                }

            }

            JSONArray childrens = json.getJSONArray("children");
            if (childrens != null && childrens.size() > 0) {
                buildUserDeptTreeForWeb(list, childrens);
            }
        }

    }


    /**
     * 查询用户权限人员
     *
     * @return
     */
    @ApiOperation(value = "人员查询", notes = "人员查询")
    @RequestMapping(value = "/queryAuthUsers", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    // @Authorization(ingore = true)
    public CommonResponse queryAllUser() {
        ReginParams reginParams = getSelectedOrgInfo();
        String loginOrgCode = getLoginOrgCode(reginParams);
        List<AgencyUserModel> userModels = remoteSecurityService.listUserByOrgCode(getToken(), getProduct(), getAppKey(), loginOrgCode);
        List<LinkedHashMap<String, Object>> userList = paraseData(userModels, null);
        return CommonResponseUtil.success(userList);
    }

    /**
     * 查询用户部门人员树
     *
     * @return
     */
    @ApiOperation(value = "部门人员树查询", notes = "部门人员树查询")
    @RequestMapping(value = "/queryDeptUserTree", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse queryDeptUserTree() {
        ReginParams reginParams = getSelectedOrgInfo();
        String departmentId = getDepartmentId(reginParams);
        List<AgencyUserModel> userModels = remoteSecurityService.listUserByDepartmentId(getToken(), getProduct(), getAppKey(), departmentId);
        List<LinkedHashMap<String, Object>> userList = paraseData(userModels, null);
        return CommonResponseUtil.success(userList);
    }

    /**
     * 查询用户部门人员树
     *
     * @return
     * @RequestParam userName 用户名
     */

    @ApiOperation(value = "通讯录(<font color='blue'>手机app</font>)", notes = "通讯录(<font color='blue'>手机app</font>)")
    @RequestMapping(value = "/queryUserAddressList", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse queryUserAddressListTree(
      @ApiParam(value = "用户名") @RequestParam(value = "userName", required = false) String userName) {
        ReginParams reginParams = getSelectedOrgInfo();
        String companyId = getCompanyId(reginParams);
        List<DepartmentModel> treeBos = remoteSecurityService.getDepartmentTreeByCompanyId(getToken(), getProduct(), getAppKey(), companyId);
        List<LinkedHashMap<String, Object>> content = new ArrayList<>();
        return CommonResponseUtil.success(content);
    }


    private List<LinkedHashMap<String, Object>> paraseData(List<AgencyUserModel> list, String userNmae) {
        List<LinkedHashMap<String, Object>> userList = new ArrayList<>();
        if (!ObjectUtils.isEmpty(list)) {
            for (AgencyUserModel userModel : list) {
                LinkedHashMap<String, Object> user = new LinkedHashMap<>();
                user.put("id", userModel.getUserId());
                user.put("key", userModel.getUserId());
                user.put("value", userModel.getUserId());
                user.put("checked", false);
                user.put("state", "open");
                user.put("name", userModel.getRealName());
                user.put("desc", null);
                user.put("writeable", 0);
                user.put("userName", userModel.getUserId());
                user.put("mobile", userModel.getMobile());
                user.put("telephone", userModel.getLandlinePhone());
                user.put("departmentName", "其他");
               userList.add(user);
            }
        }

        return userList;
    }

    private List<LinkedHashMap<String, Object>> filterUser(List<LinkedHashMap<String, Object>> tempChildren,
                                                           String userNmae) {
        List<LinkedHashMap<String, Object>> userList = new ArrayList<LinkedHashMap<String, Object>>();
        if (ObjectUtils.isEmpty(tempChildren)) {
            return userList;
        }
        userList.forEach((item) -> {
            if (!ObjectUtils.isEmpty(userNmae) && item.get("label").toString().indexOf(userNmae) != -1) {
                userList.add(item);
            }
        });
        return userList;
    }


    @ApiOperation(value = "用户登录成功之后数据初始化(<font color='blue'>手机app</font>)", notes = "用户登录成功之后数据初始化")
    @RequestMapping(value = "/initData", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse initUserApp() {
        try {
        	 ReginParams reginParams = getSelectedOrgInfo();
            CommonResponse secResponse = remoteSecurityService.searchPermissionTree(Long.valueOf(reginParams.getRole().getSequenceNbr()),getToken(), getProduct(), getAppKey(), appType);
            if (!secResponse.isSuccess()) {
                return CommonResponseUtil.failure("权限获取失败");
            }
            List<LinkedHashMap<String, Object>> response = new ArrayList<>();
            HashMap<String, Object> resp = new HashMap<>();
            resp.put("permissionitems", secResponse.getDataList());
            resp.put("companys", response);
            return CommonResponseUtil.success(resp);
        } catch (Exception e) {
            return CommonResponseUtil.failure("数据初始化失败");
        }
    }

    ///////////////////////////////2019-11-18安全服务升级///////////////////////////////

    @ApiOperation(value = "通讯录", notes = "通讯录")
    @RequestMapping(value = "/mobile/addressList", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse addressList() {
        try {
        	
            ReginParams reginParams = getSelectedOrgInfo();
            CompanyBo companyBo = reginParams.getCompany();
            JSONArray arr = remoteSecurityService.listDepartmentUserTree(getToken(), getProduct(), getAppKey(), companyBo.getSequenceNbr());
            DepartmentUserTreeAppVo departmentUserTreeDto = new DepartmentUserTreeAppVo();
            if (arr != null && arr.size() > 0) {
               
                buildUserDeptTree(departmentUserTreeDto, arr);
            }
            DepartmentUserTreeAppVo qi=new DepartmentUserTreeAppVo();
            List<DepartmentUserTreeAppVo>  list=  departmentUserTreeDto.getChildren();
            List<DepartmentUserTreeAppVo>  listdate=new ArrayList<>();
            for (DepartmentUserTreeAppVo departmentUserTreeAppVo : list) {
            	if("其他".equals(departmentUserTreeAppVo.getName())){
            		qi=departmentUserTreeAppVo;
            		qi.setId("-0");
            		qi.setType("dep");
                }else{
                	listdate.add(departmentUserTreeAppVo);
                }
			}
            if(qi!=null){
            	listdate.add(qi);
            }
            return CommonResponseUtil.success(listdate);
        } catch (Exception e) {
            logger.error("通讯录异常", e);
            return CommonResponseUtil.failure("系统繁忙，请稍后再试");
        }
    }

    private void buildUserDeptTree(DepartmentUserTreeAppVo deptUser, JSONArray childs) {
        for (int i = 0; i < childs.size(); i++) {
            JSONObject json = childs.getJSONObject(i);
            DepartmentUserTreeAppVo treeDto = new DepartmentUserTreeAppVo();
            treeDto.setName(json.getString("departmentName"));
            treeDto.setId(json.getString("sequenceNbr"));
         
            	treeDto.setType(json.getString("level"));
           
            JSONArray childrens = json.getJSONArray("children");
            if (childrens != null && childrens.size() > 0) {
                buildUserDeptTree(treeDto, childrens);
            }
            JSONArray userModelList = json.getJSONArray("userModelList");
            if(userModelList != null && userModelList.size() > 0){
            	
            	UserDeptTree( treeDto,  userModelList);
            }

            deptUser.getChildren().add(treeDto);
        }
    }

    
         //部门下用户
    
      private void UserDeptTree(DepartmentUserTreeAppVo deptUser, JSONArray childs) {
    	  
    	  for (int i = 0; i < childs.size(); i++) {
              JSONObject json = childs.getJSONObject(i);
              DepartmentUserTreeAppVo treeDto = new DepartmentUserTreeAppVo();
              treeDto.setName(json.getString("realName"));
              treeDto.setId(json.getString("userId"));
              treeDto.setType("user");                         
	          Map<String, String> user = Maps.newHashMap();
	          user.put("telephone", json.getString("mobile"));
	          user.put("email", json.getString("email"));
	          treeDto.setObject(user);           
              deptUser.getChildren().add(treeDto);
          }
      }
    
    
    
    
    
    
    /**
     * APP登录
     */
    @ApiOperation(value = "APP登录", notes = "APP登录")
    @PostMapping(value = "/mobile/login")
    //@Authorization(ingore = true)
    public CommonResponse mobileLogin(@ApiParam(value = "账号", required = true) @RequestBody AppLoginUserParam param) {

	          try {
	       JSONObject jsonObject =null;  
//  		 jsonObject = remoteSecurityService.loginFromApp(param.getUserName(), param.getPassword());
  		     IdPasswordAuthModel  dPasswordAuthModel=new IdPasswordAuthModel();
  	    	 dPasswordAuthModel.setLoginId(param.getUserName());
  	    	 dPasswordAuthModel.setPassword(DesUtil.decode(param.getPassword(), "yeejoin"));
   	         HttpHeaders headers = new HttpHeaders();
  	         headers.setContentType(MediaType.APPLICATION_JSON);
  	         headers.set("Content-Type", "application/json");
  	         headers.set("product", productApp);  	           
  	         HttpEntity httpEntity = new HttpEntity<>(dPasswordAuthModel, headers);
  	         FeignClientResult feignClientResult = restTemplate.postForObject("http://"+SecurityName+"/privilege/v1/auth/idpassword",httpEntity, FeignClientResult.class);
  	  	 if (feignClientResult.getStatus() ==200 ) {
  			   Map  map = (Map) feignClientResult.getResult();  	          
  	           map.put("appKey", appKeyApp);
 			   map.put("product", productApp);
 			   String jsonStr = JSON.toJSONString(map);
	           jsonObject = JSONObject.parseObject(jsonStr);
  			 }else{
  				 return CommonResponseUtil.failure(feignClientResult.getMessage()); 
  			 }
       if (jsonObject != null) {
          JSONObject result = new JSONObject();
          result.put("token", jsonObject.getString("token"));
          result.put("userId", jsonObject.getString("userId"));
          result.put("appKey", jsonObject.getString("appKey"));
          result.put("product", jsonObject.getString("product"));
          result.put("jpushUserKey", appMessagePushService.buildJpushUserKey(jsonObject.getString("userId")));
          //删除别名关联设备
          CommonResponse commonResponse=PushFeign.PushDevice(appMessagePushService.buildJpushUserKey(jsonObject.getString("userId")));       
          return CommonResponseUtil.success(result);
      }
      return CommonResponseUtil.failure("登录失败");
  } catch (Exception e) {
      e.printStackTrace();
      logger.error("APP登录异常", e);
      return CommonResponseUtil.failure("系统繁忙，请稍后再试");
  }
    }

    @ApiOperation(value = "别名关联设备", notes = "别名关联设备")
    @PostMapping(value = "/PushDeviceRegistration/{registrationId}/{alias}")
    public CommonResponse pushDevice(@PathVariable String registrationId,@PathVariable String alias) {
        try {
        	CommonResponse commonResponse=PushFeign.PushDeviceRegistration(registrationId,alias);
        	if("SUCCESS".equals(commonResponse.getResult())){
        	 return CommonResponseUtil.success("成功");
        	}       	
        	 return CommonResponseUtil.failure("失败");          
        } catch (Exception e) {
            e.printStackTrace();        
            return CommonResponseUtil.failure("失败");
        }
    }
    /**
     * APP登出
     */
    @ApiOperation(value = "APP登出", notes = "APP登出")
    @PostMapping(value = "/mobile/loginOut")
    public CommonResponse mobileLoginOut() {
        try {
            if (remoteSecurityService.loginOutFromApp(getToken(), getProduct(), getAppKey())) {
                return CommonResponseUtil.success();
            } else {
                return CommonResponseUtil.failure("APP登出失败");
            }
        } catch (Exception e) {
            logger.error("APP登出异常", e);
            return CommonResponseUtil.failure("系统繁忙，请稍后再试");
        }
    }

    /**
     * 获取公司选择信息
     */
    @ApiOperation(value = "获取公司选择信息", notes = "获取公司选择信息")
    @GetMapping(value = "/selectInfo")
    public CommonResponse selectInfo() {
        try {
            JSONObject result = new JSONObject();
            AgencyUserModel user = getUserInfo();
            if (user != null) {
            	List<CompanyModel>  list  =user.getCompanys();
                Map<Long, List<DepartmentModel>>  mapDepartments= user.getCompanyDepartments();
                Map<String, List<Map<String, Object>>> mapdate=new HashMap<String, List<Map<String, Object>>>();                
            	List<Map>  listCompanyModel =new ArrayList();
            	if(list!=null&&list.size()>0){
            	for (CompanyModel article : list) {                  
            		Map<String, Object>  map=   objectToMap(article);
            		map.put("companySeq", map.get("companySeq")+"");
            		map.put("parentId", map.get("parentId")+"");	
            		listCompanyModel.add(map);            		
            		long key= Long.valueOf( map.get("sequenceNbr").toString());
            		 List<DepartmentModel> listdep=mapDepartments.get(key);
                 	 List<Map<String, Object>>  dep =new ArrayList();
                 	for (DepartmentModel departmentModel : listdep) {                     	
                 		if(departmentModel!=null){
                 			Map<String, Object>  mapo=   objectToMap(departmentModel);
                    		mapo.put("sequenceNbr", mapo.get("sequenceNbr").toString());
                    		dep.add(mapo);
                 		}                		
                 	}           		
                 	mapdate.put(map.get("sequenceNbr").toString(), dep);
            	}
            	}
                result.put("companys", listCompanyModel);                             
                result.put("orgRoles", user.getOrgRoles());                
                result.put("companyDepartments", mapdate);
                return CommonResponseUtil.success(result);
            }
            return CommonResponseUtil.failure("请重新登录");
        } catch (Exception e) {
            logger.error("获取公司选择信息异常", e);
            return CommonResponseUtil.failure("系统繁忙，请稍后再试");
        }
    }

    
    @ApiOperation(value = "部门人员树查询", notes = "部门人员树查询")
    @RequestMapping(value = "/queryDeptUserTree2", produces = "application/json;charset=UTF-8", method = RequestMethod.GET)
    public CommonResponse queryDeptUserTree2() {
    	 ReginParams reginParams = getSelectedOrgInfo();
         CompanyModel companyModel = remoteSecurityService.listUserByCompanyId1(getToken(), getProduct(), getAppKey(), reginParams.getCompany().getSequenceNbr());
         List children = (List) companyModel.getChildren();
         List<DepartmentUserTreeWebVo> list = Lists.newArrayList();
         for (int i = 0; i < children.size(); i++) {
             Map<String, Object> map = (LinkedHashMap) children.get(i);
             JSONObject json = JSON.parseObject(JSON.toJSONString(map));
             DepartmentUserTreeWebVo deptTreeWeb = new DepartmentUserTreeWebVo();
             JSONArray childrens = json.getJSONArray("children");
             deptTreeWeb.setType("department");
             deptTreeWeb.setKey(map.get("sequenceNbr").toString());
             deptTreeWeb.setLabel(map.get("sequenceNbr").toString());
             deptTreeWeb.setTitle(map.get("departmentName").toString());
             deptTreeWeb.setValue(map.get("sequenceNbr").toString());
             if (!ObjectUtils.isEmpty(map.get("userModelList"))) {
                 deptTreeWeb.setUserModelList((List) map.get("userModelList"));
             }
             list.add(deptTreeWeb);
             if (childrens != null && childrens.size() > 0) {
                 buildUserDeptTreeForWebBefore(list, childrens);
             }
         }
         list = buildUserDeptTreeForWeb(list);
         return CommonResponseUtil.success(list);
     }
    
    
    
    
    //对象转map
    
    
    public static Map<String, Object> objectToMap(Object obj) throws IllegalAccessException {
    	 Map<String, Object> map = new HashMap<String,Object>();
    	if(obj!=null){       
        Class<?> clazz = obj.getClass();
        for (Field field : clazz.getDeclaredFields()) {
            field.setAccessible(true);
            String fieldName = field.getName();
            Object value = nvl(field.get(obj));
            map.put(fieldName, value);
        }
        return map;
    }
    return map;
    }
    
    public static Object nvl(Object param) {  
        return param != null ? param : "";  
    } 
    
    
    
    
    /**
     * 保存登陆用户选择公司信息
     */
    @ApiOperation(value = "保存登陆用户选择公司信息", notes = "保存登陆用户选择公司信息")
    @PostMapping(value = "/save/curCompany")
    public CommonResponse saveCurCompany(@ApiParam(value = "当前登陆用户所选单位机构编号", required = true) @RequestBody SelectUserInfo selectUserInfo) {
        try {
            AgencyUserModel user = getUserInfo();
            ReginParams reginParams = new ReginParams();
            reginParams.setCompany(selectUserInfo.getCompanyModel());
            reginParams.setRole(selectUserInfo.getRoleModel());
            reginParams.setDepartment(selectUserInfo.getDepartmentModel());
            saveSelectedOrgInfo(reginParams);
            return CommonResponseUtil.success(buildCurCompany(getToken(),getProduct(),getAppKey(),selectUserInfo, user));
        } catch (Exception e) {
            logger.error("保存登陆用户选择公司信息异常", e);
            return CommonResponseUtil.failure("系统繁忙，请稍后再试");
        }
    }

    private JSONObject buildCurCompany(String toke,String product,String appKey,SelectUserInfo selectUserInfo, AgencyUserModel user) {
        JSONObject result = new JSONObject();
        result.put("userId", user.getUserId());
        result.put("realName", user.getRealName());
        result.put("userMobile", user.getMobile());
        result.put("userName", user.getUserName());
        result.put("email", user.getEmail());

        CommonResponse secResponse = remoteSecurityService.searchPermissionTree(Long.valueOf(selectUserInfo.getRoleModel().getSequenceNbr()),toke,product,appKey,appType);
        if (secResponse.isSuccess() && secResponse.getDataList() != null) {
            JSONArray arr = JSON.parseArray(JSONArray.toJSONString(secResponse.getDataList()));
            Map<String, JSONObject> map = Maps.newHashMap();
            if (arr != null && arr.size() > 0) {
                JSONObject obj = arr.getJSONObject(0);
                if (obj != null) {
                    JSONArray childrens = obj.getJSONArray("children");
                    if (childrens != null && childrens.size() > 0) {
                        for (int i = 0; i < childrens.size(); i++) {
                            JSONObject child = childrens.getJSONObject(i);
                            map.put(child.getString("path"), child);
                        }
                    }
                }
                List<String> userHaveToDo = iAppService.getHaveToDoList(user.getUserId());
                result.put("userHaveToDo", userHaveToDo);
                result.put("userPower", map.get("appPower"));
                result.put("userShow", map.get("appMenu"));
            }
        }
        result.put("companyModel", selectUserInfo.getCompanyModel());
        result.put("departmentModel", selectUserInfo.getDepartmentModel());
        result.put("roleModel", selectUserInfo.getRoleModel());
        return result;
    }

    /**
     * 修改密码
     */
    @ApiOperation(value = " 修改密码", notes = " 修改密码")
    @PostMapping(value = "editPassword")
    public CommonResponse editPassword(@ApiParam(value = "旧密码", required = true) @RequestParam String password,
                                       @ApiParam(value = "新密码", required = true) @RequestParam String newPassword) {
      
    	 AgencyUserModel userModel = getUserInfo();
         boolean flag=false;
         
         if(password.equals(newPassword)){
        	 return CommonResponseUtil.failure("新密码不能跟旧密码相同！"); 
        	 
         }
         
         
         try {
         //flag=remoteSecurityService.editPassword(getToken(), getProduct(), getAppKey(), userModel.getUserId(), password, newPassword);
			
         	AgencyUserModel agencyUserModel=new AgencyUserModel();
             agencyUserModel.setPassword(newPassword);
             agencyUserModel.setRePassword(newPassword);
             agencyUserModel.setOriginalPassword(password);
			     HttpHeaders headers = new HttpHeaders();
		         headers.setContentType(MediaType.APPLICATION_JSON);
		         headers.set("Content-Type", "application/json");
		         headers.set("product", getProduct());
		         headers.set("token", getToken());
		         headers.set("appKey", getAppKey());
	         HttpEntity httpEntity = new HttpEntity<>(agencyUserModel, headers);
	      ResponseEntity<FeignClientResult> feignClientResult   =  restTemplate.exchange("http://"+SecurityName+"/privilege/v1/agencyuser/"+userModel.getUserId()+"/password", HttpMethod.PUT,httpEntity, FeignClientResult.class);
	  	 if (feignClientResult.getBody().getStatus() ==200 ) {
	  		CommonResponse dates =CommonResponseUtil.success();
	  		dates.setMessage("修改成功！");
	  	      return dates; 
			 }else{
				 return CommonResponseUtil.failure(feignClientResult.getBody().getMessage()); 
			 }
         
     } catch (Exception e) {
         logger.error("修改密码异常", e);
         return CommonResponseUtil.failure(e.getMessage());
     }
    }
    
    
    /**
     * 
     * 获取字典
     * 
     * */
    
    @ApiOperation(value = "查询指定的字典信息", notes = "查询指定的字典信息")
    @GetMapping(value = "listDictionaryByDictCode/{dictCode}")
    public CommonResponse listDictionaryByDictCode(  @PathVariable  String dictCode ) {
        try {
            JSONArray list= remoteSecurityService.listDictionaryByDictCode(getToken(), getProduct(), getAppKey(),  dictCode);
            
            return CommonResponseUtil.success(list);
        } catch (Exception e) {
            
            return CommonResponseUtil.failure("请求失败");
        }
    }
    
    
    
    
    
    
}