package com.yeejoin.amos.patrol.service.core.util;

import org.apache.poi.hssf.usermodel.*;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Font;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;

/**
 * @Author: xinglei
 * @Description:
 * @Date: 2020/8/23 17:22
 */
public class PoiUtil {

    public static HSSFWorkbook wb;

    /**
     * 设置标题字体
     */
    public static Font setFont(int num) {
        Font font = wb.createFont();
        font.setFontName("微软雅黑");
        font.setFontHeightInPoints((short) num);
        font.setBoldweight(Font.BOLDWEIGHT_NORMAL);
        font.setColor(HSSFColor.BLACK.index);
        return font;
    }

    /**
     * 设置标题样式
     */
    public static CellStyle setStyle(Font font, short alignCenter) {
        CellStyle style = wb.createCellStyle();
        style.setFont(font);
        style.setAlignment(alignCenter);// 左右居中
        style.setVerticalAlignment(CellStyle.VERTICAL_CENTER);// 上下居中
        style.setLocked(true);
        style.setWrapText(false);// 自动换行
        style.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
        style.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
        style.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
        style.setBorderRight(HSSFCellStyle.BORDER_THIN);//右边框
        return style;
    }

    /**
     * 设置标题内容
     */
    public static void setTitleValue(HSSFRow head, String title, CellStyle style) {
        head.setHeightInPoints(30);
        HSSFCell hssfCell = head.createCell(0);
        hssfCell.setCellValue(title);
        hssfCell.setCellStyle(style);
    }

    /**
     * 导出(前端导出,不带文件名)
     */
    public static void export( HSSFWorkbook wb, HttpServletResponse response) {
        OutputStream out = null;
        try {
            out = response.getOutputStream();
            wb.write(out);
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (out != null) {
                try {
                    out.close();
                } catch (Exception e2) {
                }
            }
        }
    }

    /**
     * 导出(前端导出,带文件名)
     */
    public static void exportFile( HSSFWorkbook wb, String fileName, HttpServletResponse response) {
        OutputStream out = null;
        try {
            out = response.getOutputStream();
            String name = URLEncoder.encode(fileName, "UTF-8");
            response.setCharacterEncoding("UTF-8");
            response.setContentType("application/force-download");
            response.setHeader("Content-Disposition", "attachment;filename=" + name + ".xls");
            wb.write(out);
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (out != null) {
                try {
                    out.close();
                } catch (Exception e2) {
                }
            }
        }
    }

    /**
     * 导出(本地导出,测试用)
     */
    public static void exportLocal(HSSFWorkbook wb, String path, String name) {
        try {
            File file = new File(path);
            OutputStream stream = new FileOutputStream(new File(file, name));
            wb.write(stream);
            stream.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
